pub trait ReflectHash {
const HASH: [u8; 32];
}Expand description
Core trait for computing structural compile-time hashes.
Types implementing this trait can be hashed at compile time to produce a unique 32-byte identifier based solely on their structure, not their names.
Deriving
Most types should use #[derive(ReflectHash)] which automatically generates
the correct implementation based on the type’s structure.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.